<?php
/**
 * Name: blackout
 * Description: Blackout your ~friendica node during a given period
 * License: MIT
 * Version: 1.0
 * Author: Tobias Diekershoff <http://diekershoff.homeunix.net/friendika/~tobias>
 *
 * This plugin will allow you to enter a date/time periode during which
 * all your ~friendica visitors from the web (so API calls and with it the
 * clients will work, as will the underlaying communication with other
 * ~friendica nodes) will be redirected to a page you can configure in
 * the admin panel as well.
 *
 * THIS ADDON REQUIRES PHP VERSION 5.3 OR HIGHER.
 *
 */


function blackout_install() {
    register_hook('page_header', 'addon/blackout/blackout.php', 'blackout_redirect');
}

function blackout_uninstall() {
    unregister_hook('page_header', 'addon/blackout/blackout.php', 'blackout_redirect');
}
function get_stamp($s) {
    logger($s);
    $tmp = explode(':',$s);
    $date=explode('-',$tmp[0]);
    $time = str_split($tmp[1],2);
    return array($date,$time);
}
function blackout_redirect ($a, $b) {
    // if we have a logged in user, don't throw her out
    if (local_user()) {
        return true;
    }
    // else...
    $mystart = get_config('blackout','begindate');
    $myend   = get_config('blackout','enddate');
    $myurl   = get_config('blackout','url');
    $now = time();
    $date1 = DateTime::createFromFormat('Y-m-d G:i', $mystart)->format('U');
    $date2 = DateTime::createFromFormat('Y-m-d G:i', $myend)->format('U');
    if (( $date1 <= $now ) && ( $now <= $date2 )) {
        logger('redirecting user to blackout page');
        goaway($myurl);
    }
}

function blackout_plugin_admin(&$a, &$o) {
    $mystart = get_config('blackout','begindate');
    if (! is_string($mystart)) { $mystart = "YYYY-MM-DD:hhmm"; }
    $myend   = get_config('blackout','enddate');
    if (! is_string($myend)) { $myend = "YYYY-MM-DD:hhmm"; }
    $myurl   = get_config('blackout','url');
    if (! is_string($myurl)) { $myurl = "http://www.example.com"; }
    $t = file_get_contents( dirname(__file__)."/admin.tpl" );
    $o = replace_macros($t, array(
        '$submit' => t('Submit'),
        '$rurl' => array("rurl", "Redirect URL", $myurl, "all your visitors from the web will be redirected to this URL"),
        '$startdate' => array("startdate", "Begin of the Blackout<br />(YYYY-MM-DD hh:mm)", $mystart, "format is <em>YYYY</em> year, <em>MM</em> month, <em>DD</em> day, <em>hh</em> hour and <em>mm</em> minute"),
        '$enddate' => array("enddate", "End of the Blackout<br />(YYYY-MM-DD hh:mm)", $myend, ""),

    ));
}
function blackout_plugin_admin_post (&$a) {
    $begindate = trim($_POST['startdate']);
    $enddate = trim($_POST['enddate']);
    $url = trim($_POST['rurl']);
    set_config('blackout','begindate',$begindate);
    set_config('blackout','enddate',$enddate);
    set_config('blackout','url',$url);
}
